#Print Functions
def add(a = 0):
    if a == 0:
        print("No Arguments Specified")
    else:  
        print(a)
        return a

def sub(a = 0):
    if a == 0:
        print("No Arguments Specified")
    else:  
        print(a)
        return a

def mul(a = 0):
    if a == 0:
        print("No Arguments Specified")
    else:  
        print(a)
        return a

def div(a = 0):
    if a == 0:
        print("No Arguments Specified")
    else:  
        print(a)
        return a

#Void Functions
def void_add(a = 0):
    if a == 0:
        print("No Arguments Specified")
    else:  
        return a

def void_sub(a = 0):
    if a == 0:
        print("No Arguments Specified")
    else:  
        return a

def void_mul(a = 0):
    if a == 0:
        print("No Arguments Specified")
    else:  
        return a

def void_div(a = 0):
    if a == 0:
        print("No Arguments Specified")
    else:  
        return a